@@ -42,7 +42,7 @@ class ApiKeyCredentials(BaseCredentials):
     """
 
     api_key: str
-    base_url: str
+    base_url: Optional[str] = ""
 
     def get_headers(self) -> dict:
         return {"Authorization": f"Bearer {self.api_key}"}
@@ -220,8 +220,7 @@ class PasswordCredentials(BaseCredentials):
 
         return headers
 
-    @staticmethod
-    def exchange_token(base_url: str, token: str, project_name: str) -> dict:
+    def exchange_token(self, project_name: str, current_groups: list[str] = []) -> dict:
         """
         Exchange an existing token for another client.
 
@@ -233,9 +232,18 @@ class PasswordCredentials(BaseCredentials):
         Returns:
             dict: Full JSON response
         """
-        url = f"{base_url}/api/v1/auth/token/exchange"
-        headers = {"Authorization": f"Bearer {token}", "Accept": "application/json"}
-        params = {"to_exchange_client_name": project_name}
+
+        if len(current_groups) > 0:
+            current_groups_value = ",".join(current_groups)
+        else:
+            current_groups_value = ""
+
+        url = f"{self.base_url}/api/v1/auth/token/exchange"
+        headers = {"Authorization": f"Bearer {self._token}", "Accept": "application/json"}
+        params = {
+            "to_exchange_client_name": project_name,
+            "current_group": current_groups_value
+        }
 
         try:
             res = requests.get(url, params=params, headers=headers)
@@ -356,6 +364,41 @@ class TokenCredentials(BaseCredentials):
             # 토큰이 만료되었을 때 refresh 시도
             return self._refresh_token()
 
+    def exchange_token(self, project_name: str, current_groups: list[str] = []) -> dict:
+        """
+        Exchange an existing token for another client.
+
+        Args:
+            base_url (str): API base URL
+            token (str): Existing access token
+            to_exchange_client_name (str): Target client name
+
+        Returns:
+            dict: Full JSON response
+        """
+        # Ensure token is authenticated before exchange
+        if self._token is None or self.is_token_expired:
+            self.authenticate()
+
+        if len(current_groups) > 0:
+            current_groups_value = ",".join(current_groups)
+        else:
+            current_groups_value = ""
+
+        url = f"{self.base_url}/api/v1/auth/token/exchange"
+        headers = {"Authorization": f"Bearer {self._token}", "Accept": "application/json"}
+        params = {
+            "to_exchange_client_name": project_name,
+            "current_group": current_groups_value
+        }
+
+        try:
+            res = requests.get(url, params=params, headers=headers)
+            res.raise_for_status()
+            return res.json()
+        except RequestException as e:
+            raise RuntimeError(f"Error during token exchange request: {str(e)}")
+
     def get_headers(self) -> dict:
         """
         Returns the headers required for API requests.
