@@ -6,7 +6,7 @@ from adxp_sdk.auth.credentials import Credentials
 from .utils import is_valid_uuid
 
 
-class AXAuthorizationHub:
+class AuthorizationHub:
     """
     SDK for managing Projects, Roles, Users, and Groups
     """
