@@ -4,7 +4,7 @@ Dataset SDK 모듈
 Dataset CRUD 기능을 제공하는 SDK입니다.
 """
 
-from .hub import AXDatasetHub
+from .hub import DatasetHub
 from .schemas import (
     DatasetCreateRequest, DatasetUpdateRequest, DatasetResponse,
     DatasetListResponse, DatasetCreateResponse, DatasetType,
@@ -13,7 +13,7 @@ from .schemas import (
 )
 
 __all__ = [
-    "AXDatasetHub",
+    "DatasetHub",
     "DatasetCreateRequest", "DatasetUpdateRequest", "DatasetResponse",
     "DatasetListResponse", "DatasetCreateResponse", "DatasetType",
     "DatasetStatus", "DatasetFile", "DatasetTag", "DatasetProcessor", 
