@@ -29,12 +29,12 @@ except ImportError:
     )
 
 
-class AXDatasetHub:
+class DatasetHub:
     """Dataset CRUD API 클라이언트 - 핵심 CRUD 기능만 제공"""
 
     def __init__(self, credentials: BaseCredentials):
         """
-        AXDatasetHub 초기화
+        DatasetHub 초기화
 
         Args:
             credentials: 인증 정보 (BaseCredentials)
