@@ -39,19 +39,19 @@ DEFAULT_SERVING_PARAMS = {
 }
 
 
-class AXModelHub:
+class ModelHub:
     """
     A class for providing model hub-related functionality (model creation, retrieval, deletion, etc).
 
     How to use:
-        >>> hub = AXModelHub(TokenCredentials(base_url="https://api.sktaip.com", username="user", password="pw", client_id="cid"))
+        >>> hub = ModelHub(TokenCredentials(base_url="https://api.sktaip.com", username="user", password="pw", client_id="cid"))
         >>> response = hub.create_model({"name": "my-model", ...})
         >>> all_models = hub.get_models()
         >>> one_model = hub.get_model_by_id("model_id")
         >>> hub.delete_model("model_id")
     """
 
-    def __init__(self, credentials: BaseCredentials, use_backend_ai: bool = False):
+    def __init__(self, credentials: BaseCredentials, base_url: Optional[str] = None, use_backend_ai: bool = False):
         """
         Initialize the model hub object.
 
@@ -61,7 +61,7 @@ class AXModelHub:
                           If False, use standard endpoints (api/v1/servings/...)
         """
         self.credentials = credentials
-        self.base_url = credentials.base_url
+        self.base_url = base_url if base_url else credentials.base_url
         self.headers = credentials.get_headers()
         self.use_backend_ai = use_backend_ai
 
