@@ -1,4 +1,4 @@
-from .hub import AXPromptHub
+from .hub import PromptHub
 from .prompt_client import PromptClient
 from .prompt_schemas import (
     PromptCreateRequest,
@@ -10,7 +10,7 @@ from .prompt_schemas import (
 )
 
 __all__ = [
-    "AXPromptHub",
+    "PromptHub",
     "PromptClient",
     "PromptCreateRequest",
     "PromptUpdateRequest", 
