@@ -10,12 +10,12 @@ from adxp_sdk.prompts.utils import replace_braces_for_prompt
 PromptVersionType = Union[Literal["latest"], Literal["release"], str]
 
 
-class AXPromptHub:
+class PromptHub:
     """
     A class for providing prompt hub-related functionality.
 
     How to use:
-        >>> hub = AXPromptHub(TokenCredentials(base_url="https://api.sktaip.com", token="your_token"))
+        >>> hub = PromptHub(TokenCredentials(base_url="https://api.sktaip.com", token="your_token"))
         >>> prompt_template = hub.get_prompt("prompt_id", "release")
     """
 
@@ -75,7 +75,7 @@ class AXPromptHub:
             version (PromptVersionType): version ("latest", "release")
 
         Example:
-            >>> hub = AXPromptHub(credentials)
+            >>> hub = PromptHub(credentials)
             >>> prompt_template = hub.get_prompt("prompt_id", "release")
 
         """
