@@ -11,8 +11,6 @@ from fastapi import FastAPI, Form, HTTPException, Request
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.openapi.utils import get_openapi
 from fastapi.responses import HTMLResponse, RedirectResponse
-from langchain.prompts import ChatPromptTemplate
-from langchain_core.messages import HumanMessage
 from langchain_core.runnables import RunnableConfig
 from langserve import add_routes
 from starlette.datastructures import MutableHeaders
